@@ -93,13 +93,12 @@ module Git
       arr_opts += log_path_options(opts)
       
       full_log = command_lines('log', arr_opts, true)
-      process_commit_data(full_log)
+
+      process_commit_log_data(full_log)
     end
-
-
     
     def revparse(string)
-      return string if string =~ /[A-Fa-f0-9]{40}/  # passing in a sha - just no-op it
+      return string if string =~ /^[A-Fa-f0-9]{40}$/  # passing in a sha - just no-op it
       rev = ['head', 'remotes', 'tags'].map do |d|
         File.join(@git_dir, 'refs', d, string)
       end.find do |path|
@@ -129,43 +128,66 @@ module Git
     end
     
     def process_commit_data(data, sha = nil, indent = 4)
-      in_message = false
-            
-      if sha
-        hsh = {'sha' => sha, 'message' => '', 'parent' => []}
-      else
-        hsh_array = []        
-      end
-    
-      data.each do |line|
-        line = line.chomp
-        if line == ''
-          in_message = !in_message
-        elsif in_message
-          hsh['message'] << line[indent..-1] << "\n"
+      hsh = {
+        'sha'     => sha,
+        'message' => '',
+        'parent'  => []
+      }
+      
+      loop do
+        key, *value = data.shift.split
+
+        break if key.nil?
+
+        if key == 'parent'
+          hsh['parent'] << value.join(' ')
         else
-          data = line.split
-          key = data.shift
-          value = data.join(' ')
-          if key == 'commit'
-            sha = value
-            hsh_array << hsh if hsh
-            hsh = {'sha' => sha, 'message' => '', 'parent' => []}
-          end
-          if key == 'parent'
-            hsh[key] << value
-          else
-            hsh[key] = value
-          end
+          hsh[key] = value.join(' ')
         end
       end
       
-      if hsh_array
-        hsh_array << hsh if hsh
-        hsh_array
-      else
-        hsh
+      hsh['message'] = data.collect {|line| line[indent..-1]}.join("\n") + "\n"
+
+      return hsh
+    end
+    
+    def process_commit_log_data(data)
+      in_message = false
+            
+      hsh_array = []       
+
+      hsh = nil
+    
+      data.each do |line|
+        line = line.chomp
+        
+        if line[0].nil?
+          in_message = !in_message 
+          next
+        end
+       
+        if in_message
+          hsh['message'] << "#{line[4..-1]}\n"
+          next
+        end
+
+        key, *value = line.split
+        value = value.join(' ')
+        
+        case key
+          when 'commit'
+            hsh_array << hsh if hsh
+            hsh = {'sha' => value, 'message' => '', 'parent' => []}
+          when 'parent'
+            hsh['parent'] << value
+          else
+            hsh[key] = value
+        end
       end
+      
+      hsh_array << hsh if hsh
+        
+      return hsh_array
     end
     
     def object_contents(sha, &block)
@@ -428,7 +450,8 @@ module Git
       arr_opts = [] 
       arr_opts << '--force' if opts[:force]
       arr_opts << '-d' if opts[:d]
-      
+      arr_opts << '-x' if opts[:x]
+
       command('clean', arr_opts)
     end
     
@@ -561,27 +584,55 @@ module Git
       command_lines('tag')
     end
 
-    def tag(tag)
-      command('tag', tag)
+    def tag(name, *opts)
+      target = opts[0].instance_of?(String) ? opts[0] : nil
+      
+      opts = opts.last.instance_of?(Hash) ? opts.last : {}
+
+      if (opts[:a] || opts[:annotate]) && !(opts[:m] || opts[:message])
+        raise  "Can not create an [:a|:annotate] tag without the precense of [:m|:message]."
+      end
+
+      arr_opts = []
+
+      arr_opts << '-f' if opts[:force] || opts[:f]
+      arr_opts << '-a' if opts[:a] || opts[:annotate]
+      arr_opts << '-s' if opts[:s] || opts[:sign]
+      arr_opts << '-d' if opts[:d] || opts[:delete]
+      arr_opts << name
+      arr_opts << target if target
+      arr_opts << "-m #{opts[:m] || opts[:message]}" if opts[:m] || opts[:message]
+      
+      command('tag', arr_opts)
     end
 
     
-    def fetch(remote)
-      command('fetch', remote)
+    def fetch(remote, opts)
+      arr_opts = [remote]
+      arr_opts << '--tags' if opts[:t] || opts[:tags]
+
+      command('fetch', arr_opts)
     end
     
-    def push(remote, branch = 'master', tags = false)
-      command('push', [remote, branch])
-      command('push', ['--tags', remote]) if tags
+    def push(remote, branch = 'master', opts = {})
+      # Small hack to keep backwards compatibility with the 'push(remote, branch, tags)' method signature.
+      opts = {:tags => opts} if [true, false].include?(opts) 
+      
+      arr_opts = []
+      arr_opts << '--force'  if opts[:force] || opts[:f]
+      arr_opts << remote
+
+      command('push', arr_opts + [branch])
+      command('push', ['--tags'] + arr_opts) if opts[:tags]
     end
 
-		def pull(remote='origin', branch='master')
-			command('pull', [remote, branch])
-		end
+    def pull(remote='origin', branch='master')
+      command('pull', [remote, branch])
+    end
 
     def tag_sha(tag_name)
       head = File.join(@git_dir, 'refs', 'tags', tag_name)
-      return File.read(head).chomp if File.exists?(head)
+      return File.read(head).chomp if File.exist?(head)
       
       command('show-ref',  ['--tags', '-s', tag_name])
     end  
@@ -668,17 +719,11 @@ module Git
     end
 
     def required_command_version
-      [1, 6, 0, 0]
+      [1, 6]
     end
 
     def meets_required_version?
-      current_version  = self.current_command_version
-      required_version = self.required_command_version
-
-      return current_version[0] >= required_version[0] && 
-             current_version[1] >= required_version[1] &&
-             (current_version[2] ? current_version[2] >= required_version[2] : true) &&
-             (current_version[3] ? current_version[3] >= required_version[3] : true)
+      (self.current_command_version <=>  self.required_command_version) >= 0
     end
 
 
@@ -703,6 +748,7 @@ module Git
       if chdir && (Dir.getwd != path)
         Dir.chdir(path) { out = run_command(git_cmd, &block) } 
       else
+
         out = run_command(git_cmd, &block)
       end
       
@@ -783,8 +829,11 @@ module Git
     end
 
     def escape(s)
+      return "'#{s && s.to_s.gsub('\'','\'"\'"\'')}'" if RUBY_PLATFORM !~ /mingw|mswin/
+      
+      # Keeping the old escape format for windows users
       escaped = s.to_s.gsub('\'', '\'\\\'\'')
-      %Q{"#{escaped}"}
+      return %Q{"#{escaped}"}
     end
 
   end
